@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-document.c 6727 2008-12-25 21:02:48Z pborelli $
+ * $Id: gedit-document.c 6777 2009-01-01 14:25:23Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -927,7 +927,7 @@ gedit_document_get_mime_type (GeditDocument *doc)
 		mime_type = g_content_type_get_mime_type (doc->priv->content_type);
 	}
 
- 	return mime_type != NULL ? g_strdup (mime_type) : g_strdup ("text/plain");
+ 	return mime_type != NULL ? mime_type : g_strdup ("text/plain");
 }
 
 /* Note: do not emit the notify::read-only signal */
