@@ -26,13 +26,13 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-encodings-option-menu.h 4429 2005-12-12 17:28:04Z pborelli $
+ * $Id: gedit-encodings-option-menu.h 6631 2008-11-29 11:06:49Z pborelli $
  */
 
 #ifndef __GEDIT_ENCODINGS_OPTION_MENU_H__
 #define __GEDIT_ENCODINGS_OPTION_MENU_H__
 
-#include <gtk/gtkoptionmenu.h>
+#include <gtk/gtk.h>
 #include <gedit/gedit-encodings.h>
 
 G_BEGIN_DECLS
