@@ -26,7 +26,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-language-manager.h 5659 2007-06-28 08:36:12Z pborelli $
+ * $Id: gedit-language-manager.h 6727 2008-12-25 21:02:48Z pborelli $
  */
 
 #ifndef __GEDIT_LANGUAGES_MANAGER_H__
@@ -39,11 +39,8 @@ G_BEGIN_DECLS
 GtkSourceLanguageManager	*gedit_get_language_manager	(void);
 
 GSList				*gedit_language_manager_list_languages_sorted
-								(GtkSourceLanguageManager	*lm);
-
-GtkSourceLanguage		*gedit_language_manager_get_language_from_mime_type 
 								(GtkSourceLanguageManager	*lm,
-								 const gchar			*mime_type);
+								 gboolean			 include_hidden);
 
 G_END_DECLS
 
