@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-view.c 6837 2009-01-11 17:03:20Z gianmt $ 
+ * $Id: gedit-view.c 6870 2009-01-30 14:30:38Z icq $ 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -47,7 +47,10 @@
 #include "gedit-prefs-manager-app.h"
 #include "gedit-marshal.h"
 #include "gedit-utils.h"
+/* FIXME: Remove this when using for more things gtk+ >= 2.15.0 */
+#if !GTK_CHECK_VERSION (2, 15, 0)
 #include "sexy-icon-entry.h"
+#endif
 
 #define GEDIT_VIEW_SCROLL_MARGIN 0.02
 #define GEDIT_VIEW_SEARCH_DIALOG_TIMEOUT (30*1000) /* 30 seconds */
@@ -1354,8 +1357,12 @@ search_entry_insert_text (GtkEditable *editable,
 static void
 customize_for_search_mode (GeditView *view)
 {
+/*
+ * FIXME: Remove all this ifdef once we require gtk+ >= 2.15.0 for other things
+ */
+#if !GTK_CHECK_VERSION (2, 15, 0)
 	GtkWidget *icon;
-
+	
 	if (view->priv->search_mode == SEARCH)
 	{
 		icon = gtk_image_new_from_stock (GTK_STOCK_FIND,
@@ -1372,13 +1379,33 @@ customize_for_search_mode (GeditView *view)
 		gtk_widget_set_tooltip_text (view->priv->search_entry,
 					     _("Line you want to move the cursor to"));
 	}
-
+	
 	gtk_widget_show (icon);
 	sexy_icon_entry_set_icon (SEXY_ICON_ENTRY(view->priv->search_entry),
 				  SEXY_ICON_ENTRY_PRIMARY,
 				  GTK_IMAGE (icon));
 
 	g_object_unref (icon);
+#else
+	if (view->priv->search_mode == SEARCH)
+	{
+		gtk_entry_set_icon_from_stock (GTK_ENTRY (view->priv->search_entry),
+					       GTK_ENTRY_ICON_PRIMARY,
+					       GTK_STOCK_FIND);
+		
+		gtk_widget_set_tooltip_text (view->priv->search_entry,
+					     _("String you want to search for"));
+	}
+	else
+	{
+		gtk_entry_set_icon_from_stock (GTK_ENTRY (view->priv->search_entry),
+					       GTK_ENTRY_ICON_PRIMARY,
+					       GTK_STOCK_JUMP_TO);
+		
+		gtk_widget_set_tooltip_text (view->priv->search_entry,
+					     _("Line you want to move the cursor to"));
+	}
+#endif
 }
 
 static gboolean
@@ -1496,7 +1523,11 @@ ensure_search_window (GeditView *view)
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 3);
 
 	/* add entry */
-	view->priv->search_entry = sexy_icon_entry_new ();				  
+#if GTK_CHECK_VERSION (2, 15, 0)
+	view->priv->search_entry = gtk_entry_new ();
+#else
+	view->priv->search_entry = sexy_icon_entry_new ();
+#endif
 	gtk_widget_show (view->priv->search_entry);
 	
 	g_signal_connect (view->priv->search_entry, "populate_popup",
